coltree_structure: Display column tree structure

View source: R/tt_showmethods.R

coltree_structureR Documentation

Display column tree structure

Description

Displays the tree structure of the columns of a table or column structure object.

Usage

coltree_structure(obj)

Arguments

obj

(ANY)
the object for the accessor to access or modify.

Value

Nothing, called for its side effect of displaying a summary to the terminal.

Examples

lyt <- basic_table() |>
  split_cols_by("ARM") |>
  split_cols_by("STRATA1") |>
  split_cols_by("SEX", nested = FALSE) |>
  analyze("AGE")

tbl <- build_table(lyt, ex_adsl)
coltree_structure(tbl)

rtables documentation built on Oct. 1, 2026, 9:07 a.m.

Related to coltree_structure in rtables...