Reporting tables often have structure that goes beyond simple rectangular data. The 'rtables' package provides a framework for declaring complex multi-level tabulations and then applying them to data. This framework models both tabulation and the resulting tables as hierarchical, tree-like objects which support sibling sub-tables, arbitrary splitting or grouping of data in row and column dimensions, cells containing multiple values, and the concept of contextual summary computations. A convenient pipe-able interface is provided for declaring table layouts and the corresponding computations, and then applying them to data.
Maintainer: Joe Zhu [email protected] (ORCID)
Authors:
Joe Zhu [email protected] (ORCID)
Gabriel Becker [email protected] (Original creator of the package)
Adrian Waddell [email protected]
Davide Garolini [email protected] (ORCID)
Emily de la Rua [email protected] (ORCID)
Other contributors:
Daniel Sabanés Bové [email protected] [contributor]
Maximilian Mordig [email protected] [contributor]
Abinaya Yogasekaram [email protected] (ORCID) [contributor]
David Munoz Tord [email protected] [contributor]
F. Hoffmann-La Roche AG [copyright holder, funder]
Useful links: