| make_subset_expr | R Documentation |
Make subset expression for a split-value pair
make_subset_expr(spl, val)
## S4 method for signature 'VarLevelSplit'
make_subset_expr(spl, val)
## S4 method for signature 'MultiVarSplit'
make_subset_expr(spl, val)
## S4 method for signature 'AnalyzeVarSplit'
make_subset_expr(spl, val)
## S4 method for signature 'AnalyzeColVarSplit'
make_subset_expr(spl, val)
## S4 method for signature 'VarStaticCutSplit'
make_subset_expr(spl, val)
## S4 method for signature 'CumulativeCutSplit'
make_subset_expr(spl, val)
## S4 method for signature 'AllSplit'
make_subset_expr(spl, val)
## S4 method for signature 'expression'
make_subset_expr(spl, val)
## S4 method for signature 'character'
make_subset_expr(spl, val)
spl |
|
val |
|
If val is a SplitValue object which already contains a
subsetting expression with length >0, that is immediately
returned. Otherwise, the appropriate subsetting expression is
constructed based on the split type of spl and the value val.
A subseting expression to be used to restrict data to a particular column during tabulation.
this is occasionally useful when constructing custom splitting behavior which may used for column splitting but generally should not be called directly by the end user.
spl <- VarLevelSplit("ARM", split_label = "ARM")
make_subset_expr(spl, "B: Placebo")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.