Learn R Programming

rtables (version 0.6.17)

make_subset_expr: Make subset expression for a split-value pair

Description

Make subset expression for a split-value pair

Usage

make_subset_expr(spl, val)

# S4 method for VarLevelSplit make_subset_expr(spl, val)

# S4 method for MultiVarSplit make_subset_expr(spl, val)

# S4 method for AnalyzeVarSplit make_subset_expr(spl, val)

# S4 method for AnalyzeColVarSplit make_subset_expr(spl, val)

# S4 method for VarStaticCutSplit make_subset_expr(spl, val)

# S4 method for CumulativeCutSplit make_subset_expr(spl, val)

# S4 method for AllSplit make_subset_expr(spl, val)

# S4 method for expression make_subset_expr(spl, val)

# S4 method for character make_subset_expr(spl, val)

Value

A subseting expression to be used to restrict data to a particular column during tabulation.

Arguments

spl

(Split)
A split object.

val

(SplitValue or string)
The value, either as a SplitValue object or the raw value as a string.

Details

If val is a SplitValue object which already contains a subsetting expression with length >0, that is immediately returned. Otherwise, the appropriate subsetting expression is constructed based on the split type of spl and the value val.

Examples

Run this code

spl <- VarLevelSplit("ARM", split_label = "ARM")
make_subset_expr(spl, "B: Placebo")

Run the code above in your browser using DataLab