Learn R Programming

rtables (version 0.6.17)

splv_extra: Access or set child-specific extra arguments on a split value

Description

splv_extra retrieves the named list of child-specific extra arguments stored on a SplitValue object. These arguments are forwarded to the analysis or content function only for the facet represented by that particular split value, making them distinct from split_exargs() which applies to all children of a split.

Usage

splv_extra(obj)

# S4 method for SplitValue splv_extra(obj)

splv_extra(obj) <- value

# S4 method for SplitValue splv_extra(obj) <- value

Value

  • splv_extra returns the current list of child-specific extra args.

  • splv_extra<- returns obj with the extra arguments replaced.

Arguments

obj

(SplitValue)
a split value object, typically produced by SplitValue() or as a result of a splitting operation.

value

(list)
named list of extra arguments to store on obj.

See Also

split_exargs() for split-level (all-children) extra arguments.

Examples

Run this code
sv <- SplitValue("A", extr = list(my_arg = 1))
splv_extra(sv)

splv_extra(sv) <- list(my_arg = 99)
splv_extra(sv)

Run the code above in your browser using DataLab